<?xml version='1.0'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version='1.0'>
<!--########################################################################### 
 |   $Id: table.mod.xsl,v 1.6 2001/08/24 23:47:55 ben Exp $
 |- ###########################################################################
 |   $Author: ben $
 |
 |   This file comes from the DB2LaTeX XSLT Stylesheets by Ramon Casellas who
 |   accepted its reuse and customization for this package.
 |
 |   PURPOSE:
 + ############################################################################
-->

<xsl:template match="table">
<xsl:text>\begin_float tab&#10;</xsl:text>
<xsl:if test="tgroup">
  \layout Standard
</xsl:if>
<xsl:apply-templates select="tgroup"/>
<xsl:text>&#10;\layout Caption&#10;</xsl:text>
<xsl:choose>
  <xsl:when test="title">
    <xsl:apply-templates select="title"/>
  </xsl:when>
  <xsl:otherwise>
    <xsl:text>***Warning: Please, add a title to figures</xsl:text>
  </xsl:otherwise>
</xsl:choose>
<xsl:text>&#10;</xsl:text>
<xsl:call-template name="label.id"/>
<xsl:text>\end_float&#10;</xsl:text>
</xsl:template>

<xsl:template match="informaltable">
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="table/title">
<xsl:call-template name="ragged.left.para"></xsl:call-template>
</xsl:template>

<xsl:template match="informaltable/title"></xsl:template>



<xsl:template match="row" mode="row-no"></xsl:template>

<xsl:template match="row[position()=last()]" mode="row-no">
  <xsl:value-of select="position()"/>
</xsl:template>


<xsl:template match="row" mode="row-border">
<xsl:text>false</xsl:text>
</xsl:template>

<xsl:template match="row[position()=last()]" mode="row-border">
<xsl:text>true</xsl:text>
</xsl:template>


<!-- Main tgroup template. Its role is to define the expected table format,
     with the column list, since this list is not so easy to do.  -->

<xsl:template match="tgroup">
<xsl:variable name="rowb">
  <xsl:apply-templates select="tbody/row" mode="row-no"/>
</xsl:variable>
<xsl:variable name="rowh">
  <xsl:choose>
  <xsl:when test="thead">1</xsl:when>
  <xsl:otherwise>0</xsl:otherwise>
  </xsl:choose>
</xsl:variable>

\begin_inset Tabular
<xsl:text>&lt;lyxtabular version="2" rows="</xsl:text>
<xsl:value-of select="$rowb + $rowh"/>
<xsl:text>" columns="</xsl:text>
<xsl:value-of select="@cols"/>
<xsl:text>"&gt;&#10;&lt;features rotate="false" islongtable="false" endhead="0" endfirsthead="0" endfoot="0" endlastfoot="0"&gt;&#10;</xsl:text>

<xsl:if test="not(colspec)">
  <xsl:call-template name="build.colspec">
    <xsl:with-param name="colno" select="@cols"/>
  </xsl:call-template>
</xsl:if>
<xsl:if test="colspec">
  <xsl:call-template name="build.colgroup">
    <xsl:with-param name="pos">1</xsl:with-param>
    <xsl:with-param name="num">1</xsl:with-param>
  </xsl:call-template>
</xsl:if>

<xsl:apply-templates/>
&lt;/lyxtabular&gt;
\end_inset 
</xsl:template>


<!-- This template builds the <column> list, according to the defined
     colspec. The difficulty is to build a column item when the related
     colspec is omitted. Besides, we must make sure that the specified
     @colnum attributes is set to the related column item. -->

<xsl:template name="build.colgroup">
  <xsl:param name="pos"/>
  <xsl:param name="num"/>

  <xsl:variable name="spec" select="colspec[position()=$pos]"/>
  <xsl:variable name="undef">
    <xsl:choose>
      <xsl:when test="$spec[@colnum > $num]">
        <xsl:value-of select="$spec/@colnum - $num"/>
      </xsl:when>
      <xsl:otherwise>0</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <!-- Create the previous omitted colspecs. -->

  <xsl:if test="$undef!=0">
    <xsl:call-template name="build.colspec">
      <xsl:with-param name="colno" select="$undef"/>
    </xsl:call-template>
  </xsl:if>

  <!-- Create the current colspec. -->

  <xsl:apply-templates select="$spec" mode="build"/>

  <xsl:if test="colspec[position()=($pos+1)]">
    <xsl:call-template name="build.colgroup">
      <xsl:with-param name="pos" select="$pos + 1"/>
      <xsl:with-param name="num" select="$num + $undef + 1"/>
    </xsl:call-template>
  </xsl:if>
</xsl:template>


<!-- Default columns list building, when no colspec specified. -->

<xsl:template name="build.colspec">
<xsl:param name="colno"/>
<xsl:if test="$colno=1">
  <xsl:text>&lt;column alignment="</xsl:text>
  <xsl:value-of select="@align"/>
  <xsl:text>" valignment="top" leftline="true" rightline="</xsl:text>
  <xsl:text>true" width="" special=""&gt;&#10;</xsl:text>
</xsl:if>
<xsl:if test="$colno>1">
  <xsl:text>&lt;column alignment="</xsl:text>
  <xsl:value-of select="@align"/>
  <xsl:text>" valignment="top" leftline="true" rightline="</xsl:text>
  <xsl:text>false" width="" special=""&gt;&#10;</xsl:text>
  <xsl:call-template name="build.colspec">
    <xsl:with-param name="colno" select="$colno - 1"/>
  </xsl:call-template>
</xsl:if>
</xsl:template>


<!-- The column building from colspec elements is done in the building
     mode, since it is a dedicated template that manages this operation.  -->

<xsl:template match="colspec"></xsl:template>

<xsl:template match="colspec[position()=last()]" mode="build">
<xsl:text>&lt;column alignment="</xsl:text>
<xsl:value-of select="@align"/>
<xsl:text>" valignment="top" leftline="true" rightline="</xsl:text>
<xsl:text>true" width="" special=""&gt;&#10;</xsl:text>
</xsl:template>

<xsl:template match="colspec" mode="build">
<xsl:text>&lt;column alignment="</xsl:text>
<xsl:value-of select="@align"/>
<xsl:text>" valignment="top" leftline="true" rightline="</xsl:text>
<xsl:text>false" width="" special=""&gt;&#10;</xsl:text>
</xsl:template>

<xsl:template match="spanspec"></xsl:template>


<xsl:template match="tbody">
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="thead">
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="row">
<xsl:apply-templates/>
</xsl:template>

<xsl:template match="thead/row|tbody/row">
<xsl:text>&lt;row topline="true" bottomline="</xsl:text>
<xsl:choose>
  <xsl:when test="position()=1 or position()=last()">
    <xsl:text>true</xsl:text>
  </xsl:when>
  <xsl:otherwise>
    <xsl:text>false</xsl:text>
  </xsl:otherwise>
</xsl:choose>
<xsl:text>" newpage="false"&gt;&#10;</xsl:text>
<xsl:apply-templates/>
&lt;/row&gt;
</xsl:template>

<xsl:template match="thead/row/entry|tbody/row/entry">
<xsl:choose>
<xsl:when test="@namest">
  <xsl:variable name="multicolno">
    <xsl:call-template name="calculate.colspan"/>
  </xsl:variable>
  <xsl:if test="$multicolno>0">
    <xsl:call-template name="build.cell">
      <xsl:with-param name="colno" select="$multicolno"/>
      <xsl:with-param name="multicol">1</xsl:with-param>
    </xsl:call-template>
  </xsl:if>
</xsl:when>
<xsl:otherwise>
  <xsl:call-template name="build.cell">
    <xsl:with-param name="colno">1</xsl:with-param>
    <xsl:with-param name="multicol">0</xsl:with-param>
  </xsl:call-template>
</xsl:otherwise>
</xsl:choose>
</xsl:template>


<!-- The cell format is complex. This template manages how to build it.
     One of the problem is to manage the multicol feature, that needs to
     recursively call the template. -->

<xsl:template name="build.cell">
<xsl:param name="colno"/>
<xsl:param name="multicol"/>

<xsl:text>&lt;cell multicolumn="</xsl:text>
<xsl:value-of select="$multicol"/>
<xsl:text>" alignment="center" valignment="top" topline="true" bottomline="</xsl:text>

<xsl:apply-templates select="(..)" mode="row-border"/>

<xsl:text>" leftline="true" rightline="</xsl:text>

<xsl:choose>
<xsl:when test="position()=last()">
  <xsl:text>true</xsl:text>
</xsl:when>
<xsl:otherwise>
  <xsl:text>false</xsl:text>
</xsl:otherwise>
</xsl:choose>

<xsl:text>" rotate="false" usebox="none" width="" special=""&gt;&#10;</xsl:text>

\begin_inset Text

\layout Standard
<xsl:apply-templates/>
\end_inset
&lt;/cell&gt;

<xsl:if test="$colno>1">
  <xsl:call-template name="build.cell">
    <xsl:with-param name="colno" select="$colno - 1"></xsl:with-param>
    <xsl:with-param name="multicol">2</xsl:with-param>
  </xsl:call-template>
</xsl:if>

</xsl:template>


<xsl:template name="colspec.colnum">
  <!-- when this macro is called, the current context must be an entry -->
  <xsl:param name="colname"></xsl:param>
  <!-- .. = row, ../.. = thead|tbody, ../../.. = tgroup -->
  <xsl:param name="colspecs" select="../../../../tgroup/colspec"/>
  <xsl:param name="count">1</xsl:param>
  <xsl:param name="colnum">1</xsl:param>
  <xsl:choose>
    <xsl:when test="$count>count($colspecs)"></xsl:when>
    <xsl:otherwise>
      <xsl:variable name="colspec" select="$colspecs[$count=position()]"/>
<!--
      <xsl:value-of select="$count"/>:
      <xsl:value-of select="$colspec/@colname"/>=
      <xsl:value-of select="$colnum"/>
-->
      <xsl:choose>
        <xsl:when test="$colspec/@colname=$colname">
          <xsl:choose>
            <xsl:when test="$colspec/@colnum">
              <xsl:value-of select="$colspec/@colnum"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$colnum"/>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:when>
        <xsl:otherwise>
          <xsl:call-template name="colspec.colnum">
            <xsl:with-param name="colname" select="$colname"/>
            <xsl:with-param name="colspecs" select="$colspecs"/>
            <xsl:with-param name="count" select="$count+1"/>
            <xsl:with-param name="colnum">
              <xsl:choose>
                <xsl:when test="$colspec/@colnum">
                  <xsl:value-of select="$colspec/@colnum + 1"/>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="$colnum + 1"/>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:with-param>
           </xsl:call-template>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="colspec.colwidth">
  <!-- when this macro is called, the current context must be an entry -->
  <xsl:param name="colname"></xsl:param>
  <!-- .. = row, ../.. = thead|tbody, ../../.. = tgroup -->
  <xsl:param name="colspecs" select="../../../../tgroup/colspec"/>
  <xsl:param name="count">1</xsl:param>
  <xsl:choose>
    <xsl:when test="$count>count($colspecs)"></xsl:when>
    <xsl:otherwise>
      <xsl:variable name="colspec" select="$colspecs[$count=position()]"/>
      <xsl:choose>
        <xsl:when test="$colspec/@colname=$colname">
          <xsl:value-of select="$colspec/@colwidth"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:call-template name="colspec.colwidth">
            <xsl:with-param name="colname" select="$colname"/>
            <xsl:with-param name="colspecs" select="$colspecs"/>
            <xsl:with-param name="count" select="$count+1"/>
          </xsl:call-template>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="calculate.colspan">
  <xsl:variable name="scol">
    <xsl:call-template name="colspec.colnum">
      <xsl:with-param name="colname" select="@namest"/>
    </xsl:call-template>
  </xsl:variable>
  <xsl:variable name="ecol">
    <xsl:call-template name="colspec.colnum">
      <xsl:with-param name="colname" select="@nameend"/>
    </xsl:call-template>
  </xsl:variable>
  <xsl:value-of select="$ecol - $scol + 1"/>
</xsl:template>

</xsl:stylesheet>
